==> deepin-deb-installer_1.2.9.orig.tar.gz: deepin-deb-installer-1.2.9/translations/deepin-deb-installer_es_419.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_419" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="62"/>
        <source>Dark Theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="88"/>
        <source>Deepin Package Manager</source>
        <translation>Gestor de paquetes Deepin</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="293"/>
        <source>Bulk Install</source>
        <translation>Instalación en lote</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Error en la instalación, comprueba tu conexión de red</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>Error en la instalación: compruebe las actualizaciones en el Centro de Control</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Error de instalación, espacio insuficiente en disco</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Instalación fallida</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Dependencias rotas: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>Difiere la arquitectura del paquete </translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="52"/>
        <source>Drag and drop file here</source>
        <translation>Arrastra y suelta aquí</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="76"/>
        <source>Select File</source>
        <translation>Seleccionar archivo</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Colapso</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Mostrar detalles</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Volver</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="111"/>
        <source>Installing</source>
        <translation>Instalando</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="115"/>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="119"/>
        <source>Failed</source>
        <translation>Ha fallado</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="144"/>
        <source>Same version installed</source>
        <translation>Misma versión instalada</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="147"/>
        <source>Other version installed: %1</source>
        <translation>Otra versión instalada: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Collapse</source>
        <translation>Colapso</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Display details</source>
        <translation>Mostrar detalles</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="141"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="143"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="145"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="147"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="149"/>
        <source>Back</source>
        <translation>Volver</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="151"/>
        <source>Done</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="164"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="320"/>
        <source>Installed successfully</source>
        <translation>Instalación exitosa</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="322"/>
        <source>Uninstalled successfully</source>
        <translation>Desinstalación exitosa</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="389"/>
        <source>Other version installed: %1</source>
        <translation>Otra versión instalada: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="333"/>
        <source>Uninstall Failed</source>
        <translation>Desinstalación fallida</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="159"/>
        <source>Name: </source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="387"/>
        <source>Same version installed</source>
        <translation>La misma versión está instalada</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Mostrar paquetes relacionados</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Colapso</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure to uninstall %1?
All dependencies will also be removed</source>
        <translation>¿Está seguro de desinstalar %1?
Todas las dependencias también se eliminarán</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Gestor de paquetes Deepin</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
        <translation>Gestor de paquetes Deepin es una aplicación para ayudar a los usuarios a agregar y quitar software local, soporta instalación en lote.</translation>
    </message>
</context>
</TS>

==> deepin-deb-installer_5.0.0.orig.tar.gz: deepin-deb-installer-5.0.0/translations/deepin-deb-installer_es_419.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_419" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="62"/>
        <source>Dark theme</source>
        <translation>Tema oscuro</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="88"/>
        <source>Deepin Package Manager</source>
        <translation>Gestor de paquetes Deepin</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="293"/>
        <source>Bulk Install</source>
        <translation>Instalación en lote</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Error en la instalación, comprueba tu conexión de red</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>Error en la instalación: compruebe las actualizaciones en el Centro de Control</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Error de instalación, espacio insuficiente en disco</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Instalación fallida</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Dependencias rotas: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>Difiere la arquitectura del paquete </translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="52"/>
        <source>Drag and drop file here</source>
        <translation>Arrastra y suelta aquí</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="76"/>
        <source>Select File</source>
        <translation>Seleccionar archivo</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Colapso</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Mostrar detalles</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Volver</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="111"/>
        <source>Installing</source>
        <translation>Instalando</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="115"/>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="119"/>
        <source>Failed</source>
        <translation>Ha fallado</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="144"/>
        <source>Same version installed</source>
        <translation>Misma versión instalada</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="147"/>
        <source>Other version installed: %1</source>
        <translation>Otra versión instalada: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Collapse</source>
        <translation>Colapso</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Display details</source>
        <translation>Mostrar detalles</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="141"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="143"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="145"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="147"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="149"/>
        <source>Back</source>
        <translation>Volver</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="151"/>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="164"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="320"/>
        <source>Installed successfully</source>
        <translation>Instalación exitosa</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="322"/>
        <source>Uninstalled successfully</source>
        <translation>Desinstalación exitosa</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="389"/>
        <source>Other version installed: %1</source>
        <translation>Otra versión instalada: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="333"/>
        <source>Uninstall Failed</source>
        <translation>Desinstalación fallida</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="159"/>
        <source>Name: </source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="387"/>
        <source>Same version installed</source>
        <translation>La misma versión está instalada</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Mostrar paquetes relacionados</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Colapso</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>Esta seguro que quiere desinstalar %1? Todas sus dependencias también serán eliminadas</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Gestor de paquetes Deepin</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is used to help users install and remove local packages, supporting bulk install.</source>
        <translation>El Gestor de Paquetes Deepin se usa para ayudar a los usuarios a instalar y eliminar paquetes locales, admite la instalación masiva. </translation>
    </message>
</context>
</TS>
